/*
 * @Author: dminyi 1301963064@qq.com
 * @Date: 2024-08-09 09:59:43
 * @LastEditors: dminyi 1301963064@qq.com
 * @LastEditTime: 2024-08-28 14:38:20
 * @FilePath: \gzDyh\gz-customerSystem\src\views\basicInformation\organization\index.jsx
 * @Description: 来访登记
 */

import React, { useState, useRef, Fragment } from "react";
import NewPage from '@/components/NewPage';
import * as $$ from '@/utils/utility';
import "@arco-themes/react-gzzz/css/arco.css";
import '../index.less';
import { Space } from 'antd';
import { Button, Steps, Tabs } from '@arco-design/web-react';
import VisitorRegister from './component/visitorRegister';
import Preview from './preview';
import MattersInfo from './component/MattersInfo';
import { question, register, Matter, transfer } from '@/assets/images'

const Step = Steps.Step;
const TabPane = Tabs.TabPane;

function getCaseDataApi(submitData) {
	return $$.ax.request({ url: `caseInfo/getCaseInfo?id=${submitData}`, type: 'get', service: 'mediate' });
}



const Organization = () => {
	const formRef = useRef();

	const [isReview, setIsReview] = useState(false);//预览页面控制
	const [current, setCurrent] = useState(1);
	const [tabsActive, setTabsActive] = useState('1');
	const [tabsList, setTabList] = useState([
		{
			img: Matter,
			label: '事项详情',
			key: '1'
		},
		{
			img: transfer,
			label: '流转办理',
			key: '3',
			isNeedStep: true,//加上这个就有进度条
		},
	])


	//提交信息，需要校验规则
	const handleSubmit = async () => {
		if (formRef.current) {
			formRef.current.validate(undefined, (errors, values) => {
				console.log(errors, values);
			});
		}
	}

	//保存草稿信息,不需要校验规则
	const handleSave = async () => {
		if (formRef.current) {
			const data = formRef.current.getFields()
			console.log(data);
		}
	}

	//预览信息
	const handleReview = () => {
		setIsReview(!isReview)
	}

	function selfAcceptance() {
		$$.modalInfo({
			title: '自行受理确认',
			content: '确定自行受理吗？',
			okText: '确定受理',
			cancelText: '我再想想',
			onOk: async () => {
				setCurrent(3)
			},
		});
	}

	const breadcrumbDataMap = {
		1: { breadcrumbData: [{ title: '工作台' }, { title: '来访登记' }], title: '来访登记' },
		3: { breadcrumbData: [{ title: '工作台' }, { title: '事件中心' }], title: '办理反馈' }
	}

	return (
		<div style={{ position: 'relative' }}>
			<NewPage
				pageHead={
					breadcrumbDataMap[current]
				}
			>
				{
					current === 1 &&
					<Fragment>
						<div style={{ backgroundColor: '#fff', margin: '12px 16px 0px 16px', paddingTop: '16px', paddingLeft: '91px' }}>
							<Steps type='navigation' current={current}>
								<Step title='来访登记' disabled />
								<Step title='事件流转' disabled />
								<Step title='办理反馈' disabled />
								<Step title='结案审核' disabled />
								<Step title='当事人评价' disabled />
								<Step title='结案归档' disabled />
							</Steps>
						</div>
						{isReview ? <Preview /> : <VisitorRegister formRef={formRef} />}
						<div className="dataSync-excel">
							<Space size="large" style={{ margin: '4px 14px' }}>
								<Button type="primary" style={{ backgroundColor: '#1A6FB8' }} onClick={handleSave} >保存</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={handleReview}>预览</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={handleSubmit}>提交</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={() => selfAcceptance()}>自行受理</Button>
								<Button type='secondary' onClick={handleReview}>返回上级页面</Button>
							</Space>
						</div>
					</Fragment>
				}
				{
					current === 3 &&
					<Tabs defaultActiveTab='1' onChange={(v) => setTabsActive(v)}>
						{tabsList?.map(item => {
							return <TabPane
								key={item.key}
								title={
									<span>
										{tabsActive === item.key && <img src={item.img} alt="" style={{ width: '16px', height: '16px', margin: '-5px 12px 0px 0px' }} />}
										<span style={{ fontSize: '16px' }}>{item.label}</span>
									</span>
								}
							>
								{
									item.isNeedStep && <div style={{ backgroundColor: '#fff', margin: '12px 16px 0px 16px', paddingTop: '16px', paddingLeft: '91px' }}>
										<Steps type='navigation' current={current}>
											<Step title='来访登记' disabled />
											<Step title='事件流转' disabled />
											<Step title='办理反馈' disabled />
											<Step title='结案审核' disabled />
											<Step title='当事人评价' disabled />
											<Step title='结案归档' disabled />
										</Steps>
									</div>
								}
								<MattersInfo active={tabsActive} />
							</TabPane>
						})}
					</Tabs>
				}
			</NewPage>
		</div>
	)
}

export default Organization;